==> hp300_1.4.tar: hp300/examples/concepts/prop3.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.01")
(date "Tue 17/Sep/1991")
(component 0 "Context"
 (name "Using Delay Output Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "Counter"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Count")
     (tag "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 295 263)
     (extent 150 34)
    )
    (active detail)
   )
  )
  (component 1 "IfThenElse"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "a>1000")
   )
   (views
    (icon
    )
    (detail
     (origin 524 245)
     (extent 82 70)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 2 "Break"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 681 278)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "RepeatUntilBreak"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 155 228)
     (extent 110 64)
     (iconImage "loop.icon")
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "Delay"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Done")
     (tag "Done")
     (lock constraints)
    )
   )
   (implementation
    (component delay 3)
   )
   (views
    (icon
    )
    (detail
     (origin 145 363)
     (extent 130 34)
    )
    (active detail)
   )
  )
  (component 5 "Do"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 67 298)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "ExitThread"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 155 418)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "Break"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 681 548)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "IfThenElse"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "a>1000")
   )
   (views
    (icon
    )
    (detail
     (origin 524 515)
     (extent 82 70)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 9 "Counter"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Count")
     (tag "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 295 533)
     (extent 150 34)
    )
    (active detail)
   )
  )
  (component 10 "Delay"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Done")
     (tag "Done")
     (lock constraints)
    )
   )
   (implementation
    (component delay 3)
   )
   (views
    (icon
    )
    (detail
     (origin 145 633)
     (extent 130 34)
    )
    (active detail)
   )
  )
  (component 11 "RepeatUntilBreak"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 155 498)
     (extent 110 64)
     (iconImage "loop.icon")
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 12 "Do"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 67 568)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 13 "Start"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 57 242)
     (extent 67 37)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 14 "Start"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 57 502)
     (extent 67 37)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 15 "Note"
   (name "Delay works as Expected")
   (interface
   )
   (implementation
    (component text 4 5
     The 3-second delay stops the thread by allowing
     the Exit Thread object to execute once the delay
     time has expired.  It is not necessary for the
     parallel Until Break objects to complete. 
    )
   )
   (views
    (icon
     (extent 217 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 354 629)
     (extent 453 83)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 16 "Note"
   (name "Doesn\'t work as Expected")
   (interface
   )
   (implementation
    (component text 4 5
     The 3-second delay does not stop the thread,
     since no Sequence Out pins on any object can
     fire until all parallel objects have executed.
     The Until Break must reach terminal count first.
    )
   )
   (views
    (icon
     (extent 226 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 364 359)
     (extent 453 83)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 17 "ExitThread"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 235 688)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 18 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 422 109)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 19 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 345 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 181 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Confirm"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 421 482)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (component 1 "Note"
       (name "NotePad")
       (description 2 8
        This notepad is displayed as a Show on Execute
        panel to present the information to the reader.
       )
       (interface
       )
       (implementation
        (component text 31 9
         PURPOSE:      Illustrates new feature of Delay object in release A.00.01.
         
         USER INPUT REQUIRED: Press Start on each thread and observe the correctness of operation
         
         EXPLANATION:  The Release Notes in the Help menu refer to this example to explain when
                       the new feature of the Delay object can be used to advantage.  The two
                       Notepads in this example give an overview of this information.
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
        )
       )
       (views
        (icon
         (origin 410 415)
         (extent 78 25)
        )
        (detail
         (origin 25 209)
         (extent 848 437)
         (editing disabled)
        )
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 48 78)
       (extent 849 571)
       (panel
        (origin 18 164)
        (extent 845 533)
        (widget 0 icon
         (title off)
         (origin 417 649)
         (extent 58 37)
        )
        (widget 1 detail
         (title off)
         (origin 25 175)
         (extent 832 463)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 332 418)
       (extent 217 25)
      )
      (detail
       (origin 17 160)
       (extent 866 520)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 408)
     (extent 110 25)
    )
    (panel
     (origin 71 112)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 173 125)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 297 362)
       (Point 342 362)
      )
      (connect D2:0 D1:1
       (Point 440 445)
       (Point 440 460)
       (Point 160 460)
       (Point 160 362)
       (Point 178 362)
      )
      (connect D0:1 D2:0
       (Point 393 352)
       (Point 440 352)
       (Point 440 415)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D3:1 D0:1)
   (connect D0:1 D1:1)
   (connect D1:1 D2:0)
   (connect D5:1 D3:0)
   (connect D5:1 D4:0)
   (connect D13:0 D5:0)
   (connect D4:0 D6:0)
   (connect D8:1 D7:0)
   (connect D9:1 D8:1)
   (connect D11:1 D9:1)
   (connect D12:1 D10:0)
   (connect D12:1 D11:0)
   (connect D14:0 D12:0)
   (connect D10:1 D17:0)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1004 664)
   (configuration
    (connect D3:1 D0:1
     (Point 267 260)
     (Point 280 260)
     (Point 280 280)
     (Point 292 280)
    )
    (connect D0:1 D1:1
     (Point 447 280)
     (Point 481 280)
    )
    (connect D1:1 D2:0
     (Point 658 260)
     (Point 720 260)
     (Point 720 275)
    )
    (connect D5:1 D3:0
     (Point 115 310)
     (Point 140 310)
     (Point 140 210)
     (Point 210 210)
     (Point 210 225)
    )
    (connect D5:1 D4:0
     (Point 115 310)
     (Point 210 310)
     (Point 210 330)
    )
    (connect D13:0 D5:0
     (Point 90 281)
     (Point 90 295)
    )
    (connect D4:0 D6:0
     (Point 210 399)
     (Point 210 415)
    )
    (connect D8:1 D7:0
     (Point 658 530)
     (Point 720 530)
     (Point 720 545)
    )
    (connect D9:1 D8:1
     (Point 447 550)
     (Point 481 550)
    )
    (connect D11:1 D9:1
     (Point 267 530)
     (Point 280 530)
     (Point 280 550)
     (Point 292 550)
    )
    (connect D12:1 D10:0
     (Point 115 580)
     (Point 210 580)
     (Point 210 600)
    )
    (connect D12:1 D11:0
     (Point 115 580)
     (Point 140 580)
     (Point 140 480)
     (Point 210 480)
     (Point 210 495)
    )
    (connect D14:0 D12:0
     (Point 90 541)
     (Point 90 565)
    )
    (connect D10:1 D17:0
     (Point 277 650)
     (Point 290 650)
     (Point 290 685)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_2.1.tar: hp300/examples/concepts/prop3.ex <==
#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Fri 23/Oct/1992")
(component 0 "ROOTCONTEXT"
 (name "Using Delay Output Example")
 (interface
 )
 (implementation
  (locked no)
  (trigMode deg)
  (nextID 20)
  (component 0 "COUNTER"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Count")
     (tag "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 245 253)
     (extent 150 34)
    )
    (active detail)
   )
  )
  (component 1 "IFTHENELSE"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "a>1000")
   )
   (views
    (icon
    )
    (detail
     (origin 474 235)
     (extent 82 70)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 2 "BREAK"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 631 268)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "REPEATUNTILBREAK"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 105 218)
     (extent 110 64)
     (iconImage "loop.icon")
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "DELAY"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Done")
     (tag "Done")
     (lock constraints)
    )
   )
   (implementation
    (component delay 3)
   )
   (views
    (icon
    )
    (detail
     (origin 95 353)
     (extent 130 34)
    )
    (active detail)
   )
  )
  (component 5 "DO"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 17 288)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "EXITTHREAD"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 105 408)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "BREAK"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 631 538)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "IFTHENELSE"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "a>1000")
   )
   (views
    (icon
    )
    (detail
     (origin 474 505)
     (extent 82 70)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 9 "COUNTER"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Count")
     (tag "Count")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 245 523)
     (extent 150 34)
    )
    (active detail)
   )
  )
  (component 10 "DELAY"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Done")
     (tag "Done")
     (lock constraints)
    )
   )
   (implementation
    (component delay 3)
   )
   (views
    (icon
    )
    (detail
     (origin 95 623)
     (extent 130 34)
    )
    (active detail)
   )
  )
  (component 11 "REPEATUNTILBREAK"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 105 488)
     (extent 110 64)
     (iconImage "loop.icon")
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 12 "DO"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 17 558)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 13 "START"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 7 232)
     (extent 67 37)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 14 "START"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 7 492)
     (extent 67 37)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 15 "NOTE"
   (name "Delay works as Expected")
   (interface
   )
   (implementation
    (component text 4 5
     The 3-second delay stops the thread by allowing
     the Exit Thread object to execute once the delay
     time has expired.  It is not necessary for the
     parallel Until Break objects to complete. 
    )
   )
   (views
    (icon
     (extent 217 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 304 619)
     (extent 453 83)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 16 "NOTE"
   (name "Doesn\'t work as Expected")
   (interface
   )
   (implementation
    (component text 4 5
     The 3-second delay does not stop the thread,
     since no Sequence Out pins on any object can
     fire until all parallel objects have executed.
     The Until Break must reach terminal count first.
    )
   )
   (views
    (icon
     (extent 226 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 314 349)
     (extent 453 83)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 17 "EXITTHREAD"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 185 678)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 18 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 372 99)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 19 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 3)
    (component 0 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 355 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
     )
     (views
      (icon
       (origin 191 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (nextID 2)
      (component 0 "CONFIRM"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 411 482)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (component 1 "NOTE"
       (name "NotePad")
       (description 2 8
        This notepad is displayed as a Show on Execute
        panel to present the information to the reader.
       )
       (interface
       )
       (implementation
        (component text 30 9
         PURPOSE:      Illustrates the Delay object
          
         USER INPUT REQUIRED: Press Start on each thread and observe the correctness of operation
         
         EXPLANATION:  The two Notepads in this example give an overview of the advantages of
                       using the Delay object.
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
         
        )
       )
       (views
        (icon
         (origin 400 415)
         (extent 78 25)
        )
        (detail
         (origin 15 209)
         (extent 848 437)
         (editing disabled)
        )
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 48 78)
       (extent 849 561)
       (panel
        (origin 28 164)
        (extent 845 533)
        (widget 0 icon
         (title off)
         (origin 427 649)
         (extent 58 37)
        )
        (widget 1 detail
         (title off)
         (origin 35 175)
         (extent 832 463)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 342 418)
       (extent 217 25)
      )
      (detail
       (origin 7 160)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 0 1)
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 655 678)
     (extent 110 25)
    )
    (panel
     (origin 21 102)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 123 115)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 307 362)
       (Point 352 362)
      )
      (connect D2:0 D1:1
       (Point 450 445)
       (Point 450 460)
       (Point 170 460)
       (Point 170 362)
       (Point 188 362)
      )
      (connect D0:1 D2:0
       (Point 403 352)
       (Point 450 352)
       (Point 450 415)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D3:1 D0:1)
   (connect D0:1 D1:1)
   (connect D1:1 D2:0)
   (connect D5:1 D3:0)
   (connect D5:1 D4:0)
   (connect D13:0 D5:0)
   (connect D4:0 D6:0)
   (connect D8:1 D7:0)
   (connect D9:1 D8:1)
   (connect D11:1 D9:1)
   (connect D12:1 D10:0)
   (connect D12:1 D11:0)
   (connect D14:0 D12:0)
   (connect D10:1 D17:0)
  )
 )
 (views
  (detail
   (origin 0 62)
   (extent 876 680)
   (configuration
    (connect D3:1 D0:1
     (Point 217 250)
     (Point 230 250)
     (Point 230 270)
     (Point 242 270)
    )
    (connect D0:1 D1:1
     (Point 397 270)
     (Point 431 270)
    )
    (connect D1:1 D2:0
     (Point 608 250)
     (Point 670 250)
     (Point 670 265)
    )
    (connect D5:1 D3:0
     (Point 65 300)
     (Point 90 300)
     (Point 90 200)
     (Point 160 200)
     (Point 160 215)
    )
    (connect D5:1 D4:0
     (Point 65 300)
     (Point 160 300)
     (Point 160 322)
    )
    (connect D13:0 D5:0
     (Point 40 271)
     (Point 40 285)
    )
    (connect D4:0 D6:0
     (Point 160 389)
     (Point 160 405)
    )
    (connect D8:1 D7:0
     (Point 608 520)
     (Point 670 520)
     (Point 670 535)
    )
    (connect D9:1 D8:1
     (Point 397 540)
     (Point 431 540)
    )
    (connect D11:1 D9:1
     (Point 217 520)
     (Point 230 520)
     (Point 230 540)
     (Point 242 540)
    )
    (connect D12:1 D10:0
     (Point 65 570)
     (Point 160 570)
     (Point 160 592)
    )
    (connect D12:1 D11:0
     (Point 65 570)
     (Point 90 570)
     (Point 90 470)
     (Point 160 470)
     (Point 160 485)
    )
    (connect D14:0 D12:0
     (Point 40 531)
     (Point 40 555)
    )
    (connect D10:1 D17:0
     (Point 227 640)
     (Point 240 640)
     (Point 240 675)
    )
   )
   (stackingOrder 0 1 2 3 4 5 6 7 8 9
     10 11 12 13 14 15 16 17 18 19)
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
